==> RsCMPX_WcdmaMeas-4.0.186-py3-none-any.whl: RsCMPX_WcdmaMeas/Implementations/WcdmaMeas/Prach/Trace/FreqError/Current.py <==
from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ......Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CurrentCls:
	"""Current commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("current", core, parent)

	def read(self) -> List[float]:
		"""SCPI: READ:WCDMa:MEASurement<instance>:PRACh:TRACe:FERRor:CURRent \n
		Snippet: value: List[float] = driver.wcdmaMeas.prach.trace.freqError.current.read() \n
		Return the values of the frequency error bar graph. \n
		Suppressed linked return values: reliability \n
			:return: frequency_error: Comma-separated list of values, one result per measured preamble (see method RsCMPX_WcdmaMeas.Configure.WcdmaMeas.Prach.mpreamble)"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:WCDMa:MEASurement<Instance>:PRACh:TRACe:FERRor:CURRent?', suppressed)
		return response

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:WCDMa:MEASurement<instance>:PRACh:TRACe:FERRor:CURRent \n
		Snippet: value: List[float] = driver.wcdmaMeas.prach.trace.freqError.current.fetch() \n
		Return the values of the frequency error bar graph. \n
		Suppressed linked return values: reliability \n
			:return: frequency_error: Comma-separated list of values, one result per measured preamble (see method RsCMPX_WcdmaMeas.Configure.WcdmaMeas.Prach.mpreamble)"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:WCDMa:MEASurement<Instance>:PRACh:TRACe:FERRor:CURRent?', suppressed)
		return response

==> RsCMPX_WcdmaMeas-5.0.40-py3-none-any.whl: RsCMPX_WcdmaMeas/Implementations/WcdmaMeas/Prach/Trace/FreqError/Current.py <==
from typing import List

from ......Internal.Core import Core
from ......Internal.CommandsGroup import CommandsGroup
from ......Internal.ArgSingleSuppressed import ArgSingleSuppressed
from ......Internal.Types import DataType


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class CurrentCls:
	"""Current commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("current", core, parent)

	def read(self) -> List[float]:
		"""SCPI: READ:WCDMa:MEASurement<instance>:PRACh:TRACe:FERRor:CURRent \n
		Snippet: value: List[float] = driver.wcdmaMeas.prach.trace.freqError.current.read() \n
		Return the bargraph values of the frequency error. \n
		Suppressed linked return values: reliability \n
			:return: frequency_error: Comma-separated list of values, one result per measured preamble (see method RsCMPX_WcdmaMeas.Configure.WcdmaMeas.Prach.mpreamble)"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'READ:WCDMa:MEASurement<Instance>:PRACh:TRACe:FERRor:CURRent?', suppressed)
		return response

	def fetch(self) -> List[float]:
		"""SCPI: FETCh:WCDMa:MEASurement<instance>:PRACh:TRACe:FERRor:CURRent \n
		Snippet: value: List[float] = driver.wcdmaMeas.prach.trace.freqError.current.fetch() \n
		Return the bargraph values of the frequency error. \n
		Suppressed linked return values: reliability \n
			:return: frequency_error: Comma-separated list of values, one result per measured preamble (see method RsCMPX_WcdmaMeas.Configure.WcdmaMeas.Prach.mpreamble)"""
		suppressed = ArgSingleSuppressed(0, DataType.Integer, False, 1, 'Reliability')
		response = self._core.io.query_bin_or_ascii_float_list_suppressed(f'FETCh:WCDMa:MEASurement<Instance>:PRACh:TRACe:FERRor:CURRent?', suppressed)
		return response
